@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -30,6 +30,7 @@ sub new {
     my $writer = delete $args{writer};
     my $header = delete $args{header};
     my $footer = delete $args{footer};
+    my $duplicate_keys = delete $args{duplicate_keys};
     my $yaml_version = $class->_arg_yaml_version(delete $args{yaml_version});
     my $default_yaml_version = $yaml_version->[0];
     my $version_directive = delete $args{version_directive};
@@ -67,6 +68,7 @@ sub new {
         parser => $parser,
         default_yaml_version => $default_yaml_version,
         preserve => $preserve,
+        duplicate_keys => $duplicate_keys,
     );
     my $dumper = YAML::PP::Dumper->new(
         schema => $default_schema,
@@ -204,6 +206,7 @@ sub preserved_mapping {
     %$data = %$hash;
     my $t = tied %$data;
     $t->{style} = $args{style};
+    $t->{alias} = $args{alias};
     return $data;
 }
 
@@ -214,6 +217,7 @@ sub preserved_sequence {
     push @$data, @$array;
     my $t = tied @$data;
     $t->{style} = $args{style};
+    $t->{alias} = $args{alias};
     return $data;
 }
 
@@ -360,7 +364,8 @@ sub new {
 }
 sub value { $_[0]->{value} }
 sub tag { $_[0]->{tag} }
-sub style { $_[0]->{style} }
+sub style { $_[0]->{style} || 0 }
+sub alias { $_[0]->{alias} }
 
 1;
 
@@ -512,6 +517,8 @@ Options:
 
 Values: C<perl> (currently default), C<JSON::PP>, C<boolean>
 
+This option is for loading and dumping.
+
 Note that when dumping, only the chosen boolean style will be recognized.
 So if you choose C<JSON::PP>, C<boolean> objects will not be recognized
 as booleans and will be dumped as ordinary objects (if you enable the
@@ -521,6 +528,8 @@ Perl schema).
 
 Default: C<['Core']>
 
+This option is for loading and dumping.
+
 Array reference. Here you can define what schema to use.
 Supported standard Schemas are: C<Failsafe>, C<JSON>, C<Core>, C<YAML1_1>.
 
@@ -533,6 +542,8 @@ Additionally you can add further schemas, for example C<Merge>.
 
 Default: 'allow' but will be switched to fatal in the future for safety!
 
+This option is for loading only.
+
 Defines what to do when a cyclic reference is detected when loading.
 
     # fatal  - die
@@ -540,10 +551,36 @@ Defines what to do when a cyclic reference is detected when loading.
     # ignore - replace with undef
     # allow  - Default
 
+=item duplicate_keys
+
+Default: 0
+
+Since version 0.027
+
+This option is for loading.
+
+The YAML Spec says duplicate mapping keys should be forbidden.
+
+When set to true, duplicate keys in mappings are allowed (and will overwrite
+the previous key).
+
+When set to false, duplicate keys will result in an error when loading.
+
+This is especially useful when you have a longer mapping and don't see
+the duplicate key in your editor:
+
+    ---
+    a: 1
+    b: 2
+    # .............
+    a: 23 # error
+
 =item indent
 
 Default: 2
 
+This option is for dumping.
+
 Use that many spaces for indenting
 
 =item width
@@ -552,6 +589,8 @@ Since version 0.025
 
 Default: 80
 
+This option is for dumping.
+
 Maximum columns when dumping.
 
 This is only respected when dumping flow collections right now.
@@ -562,18 +601,24 @@ in the future it will be used also for wrapping long strings.
 
 Default: 1
 
-Print document heaader C<--->
+This option is for dumping.
+
+Print document header C<--->
 
 =item footer
 
 Default: 0
 
+This option is for dumping.
+
 Print document footer C<...>
 
 =item yaml_version
 
 Since version 0.020
 
+This option is for loading and dumping.
+
 Default: C<1.2>
 
 Note that in this case, a directive C<%YAML 1.1> will basically be ignored
@@ -620,6 +665,8 @@ schema.
 
 Since version 0.020
 
+This option is for dumping.
+
 Default: 0
 
 Print Version Directive C<%YAML 1.2> (or C<%YAML 1.1>) on top of each YAML
@@ -631,6 +678,8 @@ Since version 0.021
 
 Default: false
 
+This option is for loading and dumping.
+
 Preserving scalar styles is still experimental.
 
     use YAML::PP::Common qw/ PRESERVE_ORDER PRESERVE_SCALAR_STYLE /;
@@ -644,6 +693,9 @@ Preserving scalar styles is still experimental.
     # Preserve block/flow style (since 0.024)
     my $yp = YAML::PP->new( preserve => PRESERVE_FLOW_STYLE );
 
+    # Preserve alias names (since 0.027)
+    my $yp = YAML::PP->new( preserve => PRESERVE_ALIAS );
+
     # Combine, e.g. preserve order and scalar style
     my $yp = YAML::PP->new( preserve => PRESERVE_ORDER | PRESERVE_SCALAR_STYLE );
 
@@ -661,14 +713,17 @@ If you load the following input:
     - |
       literal
     ---
-    block mapping:
+    block mapping: &alias
       flow sequence: [a, b]
+    same mapping: *alias
     flow mapping: {a: b}
 
+
 with this code:
 
     my $yp = YAML::PP->new(
-        preserve => PRESERVE_ORDER | PRESERVE_SCALAR_STYLE | PRESERVE_FLOW_STYLE
+        preserve => PRESERVE_ORDER | PRESERVE_SCALAR_STYLE
+                    | PRESERVE_FLOW_STYLE | PRESERVE_ALIAS
     );
     my ($hash, $styles, $flow) = $yp->load_file($file);
     $yp->dump_file($hash, $styles, $flow);
@@ -676,6 +731,21 @@ with this code:
 Then dumping it will return the same output.
 Only folded block scalars '>' cannot preserve the style yet.
 
+Note that YAML allows repeated definition of anchors. They cannot be preserved
+with YAML::PP right now. Example:
+
+    ---
+    - &seq [a]
+    - *seq
+    - &seq [b]
+    - *seq
+
+Because the data could be shuffled before dumping again, the anchor definition
+could be broken. In this case repeated anchor names will be discarded when
+loading and dumped with numeric anchors like usual.
+
+Implementation:
+
 When loading, hashes will be tied to an internal class
 (C<YAML::PP::Preserve::Hash>) that keeps the key order.
 
@@ -689,8 +759,8 @@ a scalar, the object will be replaced by a simple scalar.
 You can also pass C<1> as a value. In this case all preserving options will be
 enabled, also if there are new options added in the future.
 
-There are also methods to craete preserved nodes from scratch. See the
-C<preserved_(scalar|mapping|sequence> L<"METHODS"> below.
+There are also methods to create preserved nodes from scratch. See the
+C<preserved_(scalar|mapping|sequence)> L<"METHODS"> below.
 
 =back
 
@@ -1123,7 +1193,7 @@ they will be dumped with double quotes.
 It will recognize JSON::PP::Boolean and boolean.pm objects and dump them
 correctly.
 
-Numbers which also have a PV flag will be recognized as numbers and not
+Numbers which also have a C<PV> flag will be recognized as numbers and not
 as strings:
 
     my $int = 23;
